"use strict";

var _helpers = require("../helpers");

jest.mock('js-file-download');
jest.mock('axios', () => ({
  get: jest.fn().mockResolvedValueOnce({
    data: {
      values: ['Foo', 'Bar']
    }
  }).mockResolvedValue({
    data: {
      values: [{
        id: '1',
        name: 'Foo'
      }, {
        id: '2',
        name: 'Bar'
      }]
    }
  })
}));
describe('q3-ui-rest helpers', () => {
  describe('getFn', () => {
    it('should throw an error on unknown function', () => expect(() => (0, _helpers.getFn)({
      bar: jest.fn()
    }, 'foo')).toThrowError());
    it('should call method', () => {
      const foo = jest.fn();
      (0, _helpers.getFn)({
        foo
      }, 'foo');
      expect(foo).toHaveBeenCalled();
    });
  });
  describe('isEmpty', () => {
    it('should return truthy', () => expect((0, _helpers.isEmpty)({})).toBeTruthy());
    it('should return falsy', () => expect((0, _helpers.isEmpty)({
      foo: 'bar'
    })).toBeFalsy());
  });
  describe('makePath', () => {
    it('should return nested url', () => expect((0, _helpers.makePath)(['foo', 'bar/'])).toMatch('/foo/bar'));
    it('should strip leading slashes', () => expect((0, _helpers.makePath)(['/foo', '/bar'])).toMatch('/foo/bar'));
    it('should preserve internal slashes', () => expect((0, _helpers.makePath)(['/foo/bar', '/quux'])).toMatch('/foo/bar/quux'));
  });
  describe('getOptions', () => {
    it('should return simple array without path', () => expect((0, _helpers.getOptions)('/', 'values')).resolves.toEqual(['Foo', 'Bar']));
    it('should add label and value properties', () => expect((0, _helpers.getOptions)('/', 'values', 'name')).resolves.toEqual([{
      label: 'Foo',
      value: '1',
      id: '1',
      name: 'Foo'
    }, {
      label: 'Bar',
      value: '2',
      id: '2',
      name: 'Bar'
    }]));
    it('should return just the property', () => expect((0, _helpers.getOptions)('/', 'values', 'name', true)).resolves.toEqual(['Foo', 'Bar']));
  });
  describe('acceptCsvFiletype', () => {
    it('should assign "accept" header', () => {
      const headers = {};
      (0, _helpers.acceptCsvFiletype)({})({}, headers);
      expect(headers.Accept).toMatch('text/csv');
    });
  });
});